summaryrefslogtreecommitdiff
path: root/src/common/include/gudhi/Clock.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/include/gudhi/Clock.h')
-rw-r--r--src/common/include/gudhi/Clock.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/common/include/gudhi/Clock.h b/src/common/include/gudhi/Clock.h
index 00ab2f27..6966aaaa 100644
--- a/src/common/include/gudhi/Clock.h
+++ b/src/common/include/gudhi/Clock.h
@@ -41,9 +41,9 @@ class Clock {
return msg;
}
// Print current value to std::cout
void print() const {
- std::cout << *this << std::endl;
+ std::clog << *this << std::endl;
}
friend std::ostream& operator<<(std::ostream& stream, const Clock& clock) {
@@ -41,9 +41,9 @@ class Clock {
return msg;
}
- // Print current value to std::cout
+ // Print current value to std::clog
void print() const {